@@ -1,4 +1,5 @@
-from inferelator_prior.motifs._motif import (Motif, motifs_to_dataframe, chunk_motifs,
+from inferelator_prior.motifs._motif import (Motif, motifs_to_dataframe, chunk_motifs, select_motifs, truncate_motifs,
                                      INFO_COL, MOTIF_COL, ENTROPY_COL, LEN_COL, OCC_COL, MOTIF_NAME_COL, SCAN_SCORE_COL,
                                      SCORE_PER_BASE)
 from inferelator_prior.motifs.motif_scan import MotifScan
+from inferelator_prior.motifs.motif_loader import load_motif_file
